Hoa Nguyen has uploaded this change for review. ( https://gem5-review.googlesource.com/c/public/gem5/+/44626 )

Change subject: configs: Fix stats name in arm/fs_power.py
......................................................................

configs: Fix stats name in arm/fs_power.py

In the config, there are stats having name changed:
- overall_misses -> overallMisses
- sim_seconds -> simSeconds
- overall_accesses -> overallAccesses

JIRA: https://gem5.atlassian.net/browse/GEM5-957

Signed-off-by: Hoa Nguyen <hoangu...@ucdavis.edu>
Change-Id: I35faa72b12320e6b41833f601eb23604358b3d42
---
M configs/example/arm/fs_power.py
1 file changed, 4 insertions(+), 4 deletions(-)



diff --git a/configs/example/arm/fs_power.py b/configs/example/arm/fs_power.py
index 1c7b6b7..7ae9cf8 100644
--- a/configs/example/arm/fs_power.py
+++ b/configs/example/arm/fs_power.py
@@ -51,8 +51,8 @@
         # 2A per IPC, 3pA per cache miss
         # and then convert to Watt
         self.dyn =  "voltage * (2 * {}.ipc + 3 * 0.000000001 * " \
- "{}.dcache.overall_misses / sim_seconds)".format(cpu_path, - cpu_path) + "{}.dcache.overallMisses / simSeconds)".format(cpu_path, + cpu_path)
         self.st = "4 * temp"

 class CpuPowerOff(MathExprPowerModel):
@@ -72,10 +72,10 @@
 class L2PowerOn(MathExprPowerModel):
     def __init__(self, l2_path, **kwargs):
         super(L2PowerOn, self).__init__(**kwargs)
         # Example to report l2 Cache overall_accesses
         # The estimated power is converted to Watt and will vary based
         # on the size of the cache
-        self.dyn = "{}.overall_accesses * 0.000018000".format(l2_path)
+        self.dyn = "{}.overallAccesses * 0.000018000".format(l2_path)
         self.st = "(voltage * 3)/10"

 class L2PowerOff(MathExprPowerModel):
@@ -72,10 +72,10 @@
     def __init__(self, l2_path, **kwargs):
         super(L2PowerOn, self).__init__(**kwargs)
-        # Example to report l2 Cache overall_accesses
+        # Example to report l2 Cache overallAccesses
         # The estimated power is converted to Watt and will vary based
         # on the size of the cache

--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/44626
To unsubscribe, or for help writing mail filters, visit https://gem5-review.googlesource.com/settings

Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I35faa72b12320e6b41833f601eb23604358b3d42
Gerrit-Change-Number: 44626
Gerrit-PatchSet: 1
Gerrit-Owner: Hoa Nguyen <hoangu...@ucdavis.edu>
Gerrit-MessageType: newchange
_______________________________________________
gem5-dev mailing list -- gem5-dev@gem5.org
To unsubscribe send an email to gem5-dev-le...@gem5.org
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s

Reply via email to